@@ -19,7 +19,6 @@ XML_ENCODING='utf-8'
 import libxml2
 import mobius.model.case
 import mobius.model.item
-import mobius
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Persistence layer for case
@@ -92,9 +91,10 @@ class Pickle (object):
     item.uid = int (self.__get_prop (node, 'uid'))
     item.persistent = True
     item.case = case
+    item.category = self.__get_prop (node, 'category')
 
-    category_id = self.__get_prop (node, 'category')
-    item.category = mobius.mediator.call ('category.get', category_id)
+    # @deprecated
+    item.category_obj = mobius.mediator.call ('category.get', item.category)
 
     # load children
     node = node.children
@@ -172,7 +172,7 @@ class Pickle (object):
   def save_item (self, item):
     node = libxml2.newNode ('item')
     self.__set_prop (node, 'uid', str (item.uid))
-    self.__set_prop (node, 'category', item.category.id)
+    self.__set_prop (node, 'category', item.category)
 
     # attributes
     for id, value in item.iter_attributes ():
